'use strict';

var chunkNRK5BA3E_cjs = require('./chunk-NRK5BA3E.cjs');
var chunkCU26NNP4_cjs = require('./chunk-CU26NNP4.cjs');
var path = require('path');
var core = require('@kubb/core');
var transformers = require('@kubb/core/transformers');
var pluginOas = require('@kubb/plugin-oas');
var pluginTs = require('@kubb/plugin-ts');
var pluginZod = require('@kubb/plugin-zod');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var path__default = /*#__PURE__*/_interopDefault(path);

var pluginSvelteQueryName = "plugin-svelte-query";
var pluginSvelteQuery = core.createPlugin((options) => {
  const {
    output = { path: "hooks", barrelType: "named" },
    group,
    exclude = [],
    include,
    override = [],
    parser = "client",
    transformers: transformers$1 = {},
    paramsType = "inline",
    pathParamsType = paramsType === "object" ? "object" : options.pathParamsType || "inline",
    mutation = {},
    query = {},
    paramsCasing,
    mutationKey = chunkCU26NNP4_cjs.MutationKey.getTransformer,
    queryKey = chunkCU26NNP4_cjs.QueryKey.getTransformer,
    generators = [chunkNRK5BA3E_cjs.queryGenerator, chunkNRK5BA3E_cjs.mutationGenerator].filter(Boolean),
    contentType
  } = options;
  return {
    name: pluginSvelteQueryName,
    options: {
      output,
      client: {
        importPath: "@kubb/plugin-client/clients/axios",
        dataReturnType: "data",
        pathParamsType,
        ...options.client
      },
      queryKey,
      query: query === false ? false : {
        methods: ["get"],
        importPath: "@tanstack/svelte-query",
        ...query
      },
      mutationKey,
      mutation: {
        methods: ["post", "put", "patch", "delete"],
        importPath: "@tanstack/svelte-query",
        ...mutation
      },
      paramsType,
      pathParamsType,
      parser,
      paramsCasing,
      group
    },
    pre: [pluginOas.pluginOasName, pluginTs.pluginTsName, parser === "zod" ? pluginZod.pluginZodName : void 0].filter(Boolean),
    resolvePath(baseName, pathMode, options2) {
      const root = path__default.default.resolve(this.config.root, this.config.output.path);
      const mode = pathMode ?? core.FileManager.getMode(path__default.default.resolve(root, output.path));
      if (mode === "single") {
        return path__default.default.resolve(root, output.path);
      }
      if (group && (options2?.group?.path || options2?.group?.tag)) {
        const groupName = group?.name ? group.name : (ctx) => {
          if (group?.type === "path") {
            return `${ctx.group.split("/")[1]}`;
          }
          return `${transformers.camelCase(ctx.group)}Controller`;
        };
        return path__default.default.resolve(
          root,
          output.path,
          groupName({
            group: group.type === "path" ? options2.group.path : options2.group.tag
          }),
          baseName
        );
      }
      return path__default.default.resolve(root, output.path, baseName);
    },
    resolveName(name, type) {
      let resolvedName = transformers.camelCase(name);
      if (type === "file" || type === "function") {
        resolvedName = transformers.camelCase(name, {
          isFile: type === "file"
        });
      }
      if (type === "type") {
        resolvedName = transformers.pascalCase(name);
      }
      if (type) {
        return transformers$1?.name?.(resolvedName, type) || resolvedName;
      }
      return resolvedName;
    },
    async buildStart() {
      const [swaggerPlugin] = core.PluginManager.getDependedPlugins(this.plugins, [pluginOas.pluginOasName]);
      const oas = await swaggerPlugin.context.getOas();
      const root = path__default.default.resolve(this.config.root, this.config.output.path);
      const mode = core.FileManager.getMode(path__default.default.resolve(root, output.path));
      const baseURL = await swaggerPlugin.context.getBaseURL();
      if (baseURL) {
        this.plugin.options.client.baseURL = baseURL;
      }
      const operationGenerator = new pluginOas.OperationGenerator(this.plugin.options, {
        oas,
        pluginManager: this.pluginManager,
        plugin: this.plugin,
        contentType,
        exclude,
        include,
        override,
        mode
      });
      const files = await operationGenerator.build(...generators);
      await this.addFile(...files);
      const barrelFiles = await this.fileManager.getBarrelFiles({
        type: output.barrelType ?? "named",
        root,
        output,
        files: this.fileManager.files,
        meta: {
          pluginKey: this.plugin.key
        },
        logger: this.logger
      });
      await this.addFile(...barrelFiles);
    }
  };
});

exports.pluginSvelteQuery = pluginSvelteQuery;
exports.pluginSvelteQueryName = pluginSvelteQueryName;
//# sourceMappingURL=index.cjs.map
//# sourceMappingURL=index.cjs.map